@@ -40,6 +40,7 @@ class SimpleROC(object):
             self.optimalpoints                                 = None
             self.nextfold                                      = 0
             self.fpr_fold, self.tpr_fold, self.thresholds_fold = [], [], []
+            self.scores_fold, self.labels_fold                 = [], []
             self.meanAUC, self.stdAUC, self.AUCofMeanROC       = None, None, None
             self.AUClowCI, self.AUChighCI, self.AUCs           = None, None, None
             self.mean_fpr, self.mean_tpr, self.std_tpr         = None, None, None
@@ -50,6 +51,7 @@ class SimpleROC(object):
             self.AUC, self.C, self.optimalpoints               = None, None, None
             self.nextfold                                      = 0
             self.fpr_fold, self.tpr_fold, self.thresholds_fold = [], [], []
+            self.scores_fold, self.labels_fold                 = [], []
             self.meanAUC, self.stdAUC, self.AUCofMeanROC       = None, None, None
             self.AUClowCI, self.AUChighCI, self.AUCs           = None, None, None
             self.mean_fpr, self.mean_tpr, self.std_tpr         = None, None, None
@@ -196,7 +198,7 @@ class SimpleROC(object):
     #enddef
 
     def plot_folds(self, plotTitle, showOptimalROCpoints=True, costs=None,
-                   saveFileName=None, showPlot=True):
+                   saveFileName=None, showPlot=True, showLegend=True):
         from deeproc.Helpers.ROCPlot import plotSimpleROC
         import matplotlib.pyplot as plt
         import numpy as np
@@ -245,7 +247,8 @@ class SimpleROC(object):
         self.AUChighCI    = np.minimum(self.meanAUC + (2 * self.stdAUC), 1)
         self.AUClowCI     = np.maximum(self.meanAUC - (2 * self.stdAUC), 0)
         plotSimpleROC(self.mean_fpr, self.mean_tpr, plotTitle)
-        plt.legend()
+        if showLegend:
+            plt.legend()
         # print(f'Mean ROC, AUC={self.meanAUC:0.3f} +/- {self.stdAUC:0.3f}')
         # print(f'AUC of mean ROC is {self.AUCofMeanROC:0.3f}')
 
@@ -370,6 +373,15 @@ class SimpleROC(object):
         #endif
     #enddef
 
+    def set_fold_scores_labels(self, predicted_scores=None, labels=None):
+        if predicted_scores is None or labels is None:
+            SystemError('scores and labels cannot be empty')
+
+        self.scores_fold.append(predicted_scores)
+        self.labels_fold.append(labels)
+        self.nextfold += 1
+    #enddef
+
     def set_fold(self, fpr=None, tpr=None, threshold=None):
         '''Set ROC data for a fold with fpr and tpr; threshold is optional.'''
         if fpr is None or tpr is None:
